import 'dart:convert';

import '../../src/db.dart';
import '../../src/utils.dart';

class App {
  DB _db;
  String _appStartUpId;

  App(DB db) {
    _db = db;
  }

  /// APP回到前台
  void onResume({Map<String, dynamic> extras}) async {
    int type = 2;
    // APP 启动生成本次启动ID
    if (_appStartUpId == null) {
      type = 1;
      _appStartUpId = Utils.md5(Utils.getDateNow().toString());
    }
    int disappearTime = 0;
    int appearTime = Utils.getDateNow();
    Map<String, dynamic> map = {
      "id": _appStartUpId,
      "type": type,
      "appear_time": appearTime,
      "disappear_time": disappearTime,
      "extras": json.encode(extras)
    };
    Map<String, dynamic> common = await Utils.getCommonParams();
    map.addAll(common);

    await _db.ready;
    Utils.log("app onResume", map);
    await _db.db.insert("app_tj", map);
  }

  /// APP进入后台
  void onPause() async {
    int disappearTime = Utils.getDateNow();
    Map<String, dynamic> map = {
      "id": _appStartUpId,
      "disappear_time": disappearTime,
    };
    await _db.ready;
    Utils.log("app onPause", map);
    await _db.db.insert("app_tj", map);
  }

  // 上传数据至接口
  void upload() async {
    await _db.ready;
    List<Map> list = await _db.db.query("app_tj", limit: 100, offset: 0);
    if (list.length == 0) {
      return;
    }
    String deviceId = await Utils.getDeviceId();
    bool result = await Utils.uploadData({
      "device_id": deviceId,
      "projects": [
        {"event_name": "app_stage", "event_data": list}
      ]
    });
    if (result) {
      List<String> ids = List<String>.from(list.map((e) => e['id']).toList());
      await _db.db
          .rawDelete("delete from app_tj where id in('${ids.join("','")}')");
    }
    if (Utils.isDebug) {
      Utils.log("app upload_result", {"ok": result, "length": list.length});
    }
    if (list.length == 100) {
      upload();
    }
  }
}
