import 'dart:convert';
import 'http.dart';
import 'package:crypto/crypto.dart' as crypto;
import 'package:package_info/package_info.dart';

class Utils {
  static String channel = '';
  static bool isDebug = false;
  static Http _http = Http(scheme: "http", host: "8.135.58.206", port: 8802);

  /// 设置调试模式
  static void debug() {
    isDebug = true;
  }

  /// 设置渠道
  static void setChannel(String s) {
    channel = s;
  }

  /// 获取当前时间戳，单位:秒
  static int getDateNow() {
    int now = (DateTime.now().millisecondsSinceEpoch / 1000).floor();
    return now;
  }

  // md5编码
  static String md5(String data) {
    var bytes = utf8.encode(data);
    var digest = crypto.md5.convert(bytes);
    return digest.toString();
  }

  // 获取app版本号
  static Future<String> getAppVersion() async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    String version = packageInfo.version;
    return version;
  }

  // 获取网络类型
  static Future<String> getNetworkType() async {
    return "4G";
  }

  // 获取设备ID
  static Future<String> getDeviceId() async {
    return "3A26610FFE43D5838DDE7A40BA2E3E2C";
  }

  // 获取公共参数
  static Future<Map<String, dynamic>> getCommonParams() async {
    String inter = await Utils.getNetworkType();
    String appVersion = await Utils.getAppVersion();
    return {
      "inter": inter, // 网络情况
      "app_channel": channel, // APP下载渠道
      "app_version": appVersion, // APP版本号
    };
  }

  // 上传数据
  static Future<bool> uploadData(Map<String, dynamic> body) async {
    var res = await _http.post("/collection", body);
    if (isDebug) {
      log("upload-res", res);
    }
    if (res != null && res['code'] == 200) {
      return true;
    }
    return false;
  }

  static void log(String type, Map<String, dynamic> map) {
    if (!isDebug) {
      return;
    }
    print(
        "qm_tj:$type=======================s===========================$type");
    print("qm_tj:$map");
    print(
        "qm_tj:$type=======================e===========================$type");
  }
}
